import { encodeSignedMessage, decodeSignedMessage } from "./schema.js";
import { decodeId, getKey } from "./ids.js";
export class SignedMessage {
    static decode(value, context = {}) {
        const { signature, message } = decodeSignedMessage(value);
        return new SignedMessage(signature, message, value, context);
    }
    static encode(signature, message, context = {}) {
        const value = encodeSignedMessage(signature, message);
        return new SignedMessage(signature, message, value, context);
    }
    constructor(signature, message, value, context) {
        Object.defineProperty(this, "signature", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: signature
        });
        Object.defineProperty(this, "message", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: message
        });
        Object.defineProperty(this, "value", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: value
        });
        Object.defineProperty(this, "id", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "key", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "source", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "branch", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.key = getKey(message.clock, value);
        this.id = decodeId(this.key);
        this.source = context.source;
        this.branch = context.branch;
    }
}
